Projects per language
=====================

This page lists all projects found by searching 'gnucash' on github (generated on 2020-10-24 20:47:08) excluding mirrors of the gnucash repository. Projects with a '\*' are projects that have not been updated since 12 months.

+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                     Language                     |                  # of projects                   |     # of projects updated in last 12 months      |
+==================================================+==================================================+==================================================+
|                  :ref:`Python`                   |                       171                        |                        50                        |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Unknown`                  |                        61                        |                        16                        |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Java`                    |                        42                        |                        13                        |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                :ref:`JavaScript`                 |                        25                        |                        9                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Shell`                   |                        26                        |                        6                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                :ref:`Dockerfile`                 |                        11                        |                        5                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`Go`                     |                        10                        |                        4                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                :ref:`TypeScript`                 |                        6                         |                        4                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`C#`                     |                        11                        |                        3                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Perl`                    |                        25                        |                        3                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Ruby`                    |                        17                        |                        3                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Dart`                    |                        3                         |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|             :ref:`Jupyter Notebook`              |                        5                         |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`PHP`                    |                        16                        |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Scheme`                   |                        15                        |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`Awk`                    |                        2                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`C++`                    |                        6                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`CSS`                    |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`HTML`                    |                        4                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                :ref:`Inno Setup`                 |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`PLSQL`                   |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                     :ref:`R`                     |                        2                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Rust`                    |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Scala`                   |                        3                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`TSQL`                    |                        2                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`XSLT`                    |                        4                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                     :ref:`C`                     |                        8                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Diff`                    |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`F#`                     |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|              :ref:`Gettext Catalog`              |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Groovy`                   |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Haskell`                  |                        2                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Perl6`                   |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Roff`                    |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`SQLPL`                   |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Swift`                   |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`Tcl`                    |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|               :ref:`Visual Basic`                |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+

.. _Python:

Python
------

\* `accounting-reports <https://github.com/ebridges/accounting-reports>`__ by ebridges (last commit on  2019-04-04)
	Accounting reports for GNUCash.
\* `AceMoney-to-GnuCash <https://github.com/lowvoltage/AceMoney-to-GnuCash>`__ by lowvoltage (last commit on  2015-01-11)
	A quick and dirty script to convert an AceMoney .XML into a GnuCash .XML
`alchemy <https://github.com/zmoog/alchemy>`__ by zmoog (last commit on  2020-06-05)
	A very simple Gnucash-inspired web application
\* `asset-allocation <https://github.com/MisterY/asset-allocation>`__ by MisterY (last commit on  2019-06-03)
	Asset Allocation implementation in Python
\* `bank_to_qif <https://github.com/engdan77/bank_to_qif>`__ by engdan77 (last commit on  2019-01-27)
	Program for processing XML/XLS bank account exports into QIF-format supported by e.g. GnuCash developed in Python
\* `BankCSVtoQif <https://github.com/niknow/BankCSVtoQif>`__ by niknow (last commit on  2019-08-05)
	Converts csv files from a bank to qif and replaces descriptions and target accounts according to predefined customizable rules along the way. Intended to work as a tool for gnucash.
\* `beancount2gnucash <https://github.com/wolfm89/beancount2gnucash>`__ by wolfm89 (last commit on  2018-12-23)
	Convert Beancount ledger files to GnuCash compatible files
\* `cookthebooks <https://github.com/colemannugent/cookthebooks>`__ by colemannugent (last commit on  2017-11-13)
	A python3 based, gnucash to ledger converter
\* `CSV-pre-processor-for-GnuCash <https://github.com/hughgliderpilot/CSV-pre-processor-for-GnuCash>`__ by hughgliderpilot (last commit on  2019-08-16)
	Takes transaction CSV download from bank and adds Transfer Account column based on Description
`csv2cash <https://github.com/jrwrigh/csv2cash>`__ by jrwrigh (last commit on  2020-07-13)
	Python package for importing CSV files to GNUCash
\* `csv2mt940 <https://github.com/selva-di/csv2mt940>`__ by selva-di (last commit on  2019-09-20)
	convert Sparda-West-csv to mt940 for gnucash import
\* `django-openbudget <https://github.com/evandavey/django-openbudget>`__ by evandavey (last commit on  2012-09-18)
	Simple django-based personal budgeting app that sources data from GNUCash sqlite data files
`dkb2qif <https://github.com/mzur/dkb2qif>`__ by mzur (last commit on  2020-04-05)
	Convert a DKB CSV export to QIF
`DKB_to_GnuCash <https://github.com/ch3fk0mm7/DKB_to_GnuCash>`__ by ch3fk0mm7 (last commit on  2019-12-22)
	Die CSV die man aus dem DKB Online Banking exportiert kann enthält in mehreren Spalten Informationen, die in GnuCash in die Spalte "Beschreibung" sollen, damit die Kategorie der Buchung automatisch erkannt werden kann.
`dkcash <https://github.com/quazgar/dkcash>`__ by quazgar (last commit on  2020-01-24)
	Direktkreditverwaltung mit gnucash-Backend
\* `DnbNor2qif <https://github.com/djiti/DnbNor2qif>`__ by djiti (last commit on  2011-09-19)
	Turning DnbNor CSV files into GNUCash-compatible QIF files
\* `dollar <https://github.com/marcotmarcot/dollar>`__ by marcotmarcot (last commit on  2018-04-21)
	Check if the dollar exchange rate is the same on my Gnucash transactions and UOL
\* `dropcopy <https://github.com/juniorbl/dropcopy>`__ by juniorbl (last commit on  2019-02-21)
	A simple tool for GNOME to copy a given GnuCash file to a local dropbox directory whenever it is saved.
`exporterVolksbank_GNUCash <https://github.com/vspaceone/exporterVolksbank_GNUCash>`__ by vspaceone (last commit on  2020-01-10)
	(No description available)
\* `finance_convert <https://github.com/RincewindWizzard/finance_convert>`__ by RincewindWizzard (last commit on  2017-12-01)
	Convert from Paypal and Volksbank to gnucash using csv
\* `financial_forecast <https://github.com/skullspace/financial_forecast>`__ by skullspace (last commit on  2016-09-06)
	A script to take in our Gnucash books and output a CSV with some historical and forecasted data
`flux <https://github.com/marcotmarcot/flux>`__ by marcotmarcot (last commit on  2020-07-31)
	Create a monthly flux report from a gnucash file
\* `gcimport <https://github.com/nblock/gcimport>`__ by nblock (last commit on  2014-01-12)
	Convert various input files (csv, txt) to csv files that can be easily parsed with GnuCash.
\* `gcinvoice <https://github.com/ngiger/gcinvoice>`__ by ngiger (last commit on  2019-06-04)
	GnuCash to Lates (see http://www.smoerz.org/gcinvoice/) + my personal templates
\* `generate_prices <https://github.com/barrettTom/generate_prices>`__ by barrettTom (last commit on  2019-05-20)
	gnucash price database generator script
`gnc-fq-helper <https://github.com/yegord/gnc-fq-helper>`__ by yegord (last commit on  2019-10-27)
	A drop-in replacement for GnuCash's Finance::Quote helper
\* `gnc2QuickBooks <https://github.com/jfishe/gnc2QuickBooks>`__ by jfishe (last commit on  2018-09-28)
	Python 2 convert GnuCash to QuickBooks tab delimited import format
\* `gnc_budget_scroll <https://github.com/mateuszzz88/gnc_budget_scroll>`__ by mateuszzz88 (last commit on  2016-09-18)
	This is a converter for gnucash bugdet report. It will create html with the same content, but table will be scrollable in such way, that headers (date, account name) are visible
\* `gnc_privat24 <https://github.com/gentoo90/gnc_privat24>`__ by gentoo90 (last commit on  2018-11-05)
	Imports Privat24 statements to Gnucash book
`gnc_tools <https://github.com/armanschwarz/gnc_tools>`__ by armanschwarz (last commit on  2020-08-29)
	Python tools for validating GnuCash files
`gncxml <https://github.com/LiosK/gncxml>`__ by LiosK (last commit on  2020-06-20)
	gncxml - extract entries from GnuCash data file to pandas.DataFrame
\* `gnucash-account2template <https://github.com/EvansMike/gnucash-account2template>`__ by EvansMike (last commit on  2015-09-03)
	Make a GnuCash account template from an exported account
\* `gnucash-bridge <https://github.com/dbellettini/gnucash-bridge>`__ by dbellettini (last commit on  2017-02-18)
	Expose GnuCash as a microservice
\* `gnucash-budgerow- <https://github.com/dlex/gnucash-budgerow->`__ by dlex (last commit on  2016-02-05)
	Predictive budgeter for GnuCash
\* `gnucash-budget <https://github.com/chrisbrasington/gnucash-budget>`__ by chrisbrasington (last commit on  2018-05-11)
	Minimalist budget reporting.
\* `gnucash-categorizer <https://github.com/seddonym/gnucash-categorizer>`__ by seddonym (last commit on  2017-05-22)
	(No description available)
\* `gnucash-cfdi <https://github.com/sebastianavina/gnucash-cfdi>`__ by sebastianavina (last commit on  2014-02-16)
	Proyecto que timbra facturas de gnucash por medio de facturacion moderna.
\* `gnucash-cli <https://github.com/loftx/gnucash-cli>`__ by loftx (last commit on  2019-06-30)
	(No description available)
\* `GnuCash-CSV2CSV-for-PowerBi <https://github.com/aidancrane/GnuCash-CSV2CSV-for-PowerBi>`__ by aidancrane (last commit on  2019-01-01)
	I use this to convert my GnuCash csv exports for analysis in MS Power BI
\* `gnucash-csv2html <https://github.com/m13253/gnucash-csv2html>`__ by m13253 (last commit on  2019-08-08)
	Convert CSV files exported by GnuCash to HTML format
`gnucash-docs-rst <https://github.com/codesmythe/gnucash-docs-rst>`__ by codesmythe (last commit on  2020-05-03)
	GnuCash documentation in RestructuredText as Sphinx project
\* `gnucash-expense-report <https://github.com/QuLogic/gnucash-expense-report>`__ by QuLogic (last commit on  2015-01-29)
	(No description available)
`GnuCash-Expenses-Vis <https://github.com/maciek3000/GnuCash-Expenses-Vis>`__ by maciek3000 (last commit on  2020-04-29)
	Visualizations of Expenses created in GnuCash Accounting Software
`gnucash-fiximports <https://github.com/sandeepmukherjee/gnucash-fiximports>`__ by sandeepmukherjee (last commit on  2020-03-14)
	Change target accounts of imported gnucash transactions
`gnucash-fiximports <https://github.com/jamessherring/gnucash-fiximports>`__ by jamessherring (last commit on  2020-08-01)
	(No description available)
\* `gnucash-fiximports <https://github.com/HappyPeng2x/gnucash-fiximports>`__ by HappyPeng2x (last commit on  2017-09-24)
	Additional developments on the original gnucash-fiximports
\* `gnucash-gource-viz <https://github.com/C7C8/gnucash-gource-viz>`__ by C7C8 (last commit on  2019-03-11)
	Script to convert GNUCash transaction histories into logs that can be visualized by Gource (because why not?)
\* `gnucash-import <https://github.com/manzato/gnucash-import>`__ by manzato (last commit on  2014-07-15)
	Imports transactions from a CSV file and places them to the appropriate account depending on a set of rules
`gnucash-import-stock <https://github.com/senooken/gnucash-import-stock>`__ by senooken (last commit on  2020-10-24)
	(No description available)
`gnucash-importer <https://github.com/shaform/gnucash-importer>`__ by shaform (last commit on  2020-08-29)
	Utilities to import transactions into GnuCash
\* `gnucash-importer <https://github.com/gunny26/gnucash-importer>`__ by gunny26 (last commit on  2017-12-30)
	import some csv data, categorize bookings automatically with help of some neuronal network categorizer
`gnucash-importer <https://github.com/drjeep/gnucash-importer>`__ by drjeep (last commit on  2020-08-13)
	(No description available)
\* `gnucash-importers <https://github.com/rtucker/gnucash-importers>`__ by rtucker (last commit on  2018-03-02)
	gnucash importer scripts for Interlock Rochester financial foo
`gnucash-imports <https://github.com/dpslwk/gnucash-imports>`__ by dpslwk (last commit on  2020-06-19)
	Import scripts for Nottingham Hackspace GNUCash
`gnucash-input <https://github.com/elChapoSing/gnucash-input>`__ by elChapoSing (last commit on  2020-10-06)
	personal process for DBS input into gnucash compatible file format
\* `gnucash-inteligo <https://github.com/lukasszz/gnucash-inteligo>`__ by lukasszz (last commit on  2018-04-15)
	Importowanie wyciągów z Inteligo do Gnucash,
\* `gnucash-latex <https://github.com/mwellnitz/gnucash-latex>`__ by mwellnitz (last commit on  2017-04-28)
	Create good looking invoices for gnucash using latex and python
\* `gnucash-latex-koma <https://github.com/jappeace/gnucash-latex-koma>`__ by jappeace (last commit on  2017-04-24)
	 Create good looking invoices for gnucash using latex/koma and python 
\* `gnucash-mail-sync <https://github.com/omelkova/gnucash-mail-sync>`__ by omelkova (last commit on  2018-05-06)
	(No description available)
\* `gnucash-ofx-brokerage <https://github.com/7max/gnucash-ofx-brokerage>`__ by 7max (last commit on  2012-02-18)
	GnuCash OFX importer that handles brokerages, ie stocks, mutual funds, optios
\* `gnucash-ofx-export <https://github.com/hoffie/gnucash-ofx-export>`__ by hoffie (last commit on  2014-07-14)
	Selectively export GnuCash transactions into OFX
\* `gnucash-portfolio <https://github.com/MisterY/gnucash-portfolio>`__ by MisterY (last commit on  2019-04-13)
	Tools for managing an investment portfolio in a GnuCash book
\* `gnucash-portfolio-cli <https://github.com/MisterY/gnucash-portfolio-cli>`__ by MisterY (last commit on  2019-02-04)
	Gnucash Portfolio CLI
`gnucash-portfolio-webui <https://github.com/MisterY/gnucash-portfolio-webui>`__ by MisterY (last commit on  2020-09-04)
	GnuCash Portfolio Web UI
`gnucash-prices <https://github.com/nomis/gnucash-prices>`__ by nomis (last commit on  2020-03-08)
	GnuCash price database management
\* `gnucash-pyquotehist <https://github.com/tfree87/gnucash-pyquotehist>`__ by tfree87 (last commit on  2015-06-17)
	A simple python script which imports historical price quotes from yahoo into Gnucash via the command line without the need for Perl Finance::QuoteHist. Based on Peter Holtermann's quotes_hist script
\* `Gnucash-Python-Example <https://github.com/petarkabashki/Gnucash-Python-Example>`__ by petarkabashki (last commit on  2015-02-19)
	Example python script for importing data into Gnucash
\* `gnucash-python-free <https://github.com/tbhartman/gnucash-python-free>`__ by tbhartman (last commit on  2014-08-24)
	(No description available)
\* `GNUCash-Python-Scripts <https://github.com/relyt29/GNUCash-Python-Scripts>`__ by relyt29 (last commit on  2017-05-31)
	various python scripts to add to gnucash functionality
\* `gnucash-qif-import <https://github.com/hjacobs/gnucash-qif-import>`__ by hjacobs (last commit on  2018-12-29)
	GnuCash Python helper script to import transactions from QIF text files into GnuCash's own file format
`gnucash-reconciler <https://github.com/rmehyde/gnucash-reconciler>`__ by rmehyde (last commit on  2020-08-02)
	Tool for comparing Gnucash records to bank records automatically
\* `gnucash-reports <https://github.com/MeerkatLabs/gnucash-reports>`__ by MeerkatLabs (last commit on  2019-10-03)
	Simple reporting framework for fetching data out of gnucash files for display in a viewer.
`gnucash-rest <https://github.com/loftx/gnucash-rest>`__ by loftx (last commit on  2020-10-06)
	A Python based REST framework for the Gnucash accounting application
\* `gnucash-rest-docker <https://github.com/loftx/gnucash-rest-docker>`__ by loftx (last commit on  2018-09-25)
	A dockerfile and associated files to quickly test the Gnucash Rest API
\* `gnucash-savings <https://github.com/chrisbrasington/gnucash-savings>`__ by chrisbrasington (last commit on  2018-08-24)
	gnucash-savings projection
\* `GNUCash-scripts <https://github.com/spartha80/GNUCash-scripts>`__ by spartha80 (last commit on  2019-07-28)
	Simple Python scripts to convert Bank statements to QIF format
`gnucash-scripts <https://github.com/thomasrebele/gnucash-scripts>`__ by thomasrebele (last commit on  2019-10-27)
	(No description available)
`gnucash-select <https://github.com/bulletmark/gnucash-select>`__ by bulletmark (last commit on  2020-08-15)
	GnuCash File Selector
\* `gnucash-society <https://github.com/hendrikvanantwerpen/gnucash-society>`__ by hendrikvanantwerpen (last commit on  2013-04-13)
	Support application for societies based on GnuCash
\* `gnucash-stock-portfolio <https://github.com/hjacobs/gnucash-stock-portfolio>`__ by hjacobs (last commit on  2014-01-15)
	GnuCash Python utilities to manage a stock portfolio
`gnucash-stock-quotes <https://github.com/DrSkippy/gnucash-stock-quotes>`__ by DrSkippy (last commit on  2020-08-24)
	(No description available)
\* `gnucash-to-beancount <https://github.com/henriquebastos/gnucash-to-beancount>`__ by henriquebastos (last commit on  2018-07-22)
	Gnucash to Beancount Converter.
\* `gnucash-tools <https://github.com/cnuahs/gnucash-tools>`__ by cnuahs (last commit on  2016-07-26)
	Command line tools for use with Gnucash (http://gnucash.org/).
\* `gnucash-tools <https://github.com/yanivmo/gnucash-tools>`__ by yanivmo (last commit on  2016-03-16)
	GnuCash interoperability scripts
\* `gnucash-tools <https://github.com/dahnielson/gnucash-tools>`__ by dahnielson (last commit on  2012-05-14)
	💰 Tools for working with GnuCash
`gnucash-tools <https://github.com/iqt4/gnucash-tools>`__ by iqt4 (last commit on  2020-02-16)
	(No description available)
\* `gnucash-toolset <https://github.com/cirrax/gnucash-toolset>`__ by cirrax (last commit on  2019-04-24)
	Access and manipulate gnucash data.
\* `gnucash-util <https://github.com/bstpierre/gnucash-util>`__ by bstpierre (last commit on  2011-01-21)
	Utility scripts using GnuCash python bindings
\* `gnucash-utilities <https://github.com/sdementen/gnucash-utilities>`__ by sdementen (last commit on  2017-11-23)
	Set of python scripts to work with GnuCash books
\* `gnucash-utils <https://github.com/AndreasHeger/gnucash-utils>`__ by AndreasHeger (last commit on  2015-04-08)
	utility scripts for gnucash
`gnucash-vis <https://github.com/chrlen/gnucash-vis>`__ by chrlen (last commit on  2020-05-16)
	A script to visualize state of accounts from a Gnucash file exported by the client for Android
\* `gnucash-xml-split <https://github.com/fefe982/gnucash-xml-split>`__ by fefe982 (last commit on  2014-08-30)
	Split GnuCash XML files into files containing transaction in a certain period (e.g. a year)
`gnucash2beancount <https://github.com/shaform/gnucash2beancount>`__ by shaform (last commit on  2020-09-02)
	(No description available)
\* `gnucash2googlesheets <https://github.com/erikvanegmond/gnucash2googlesheets>`__ by erikvanegmond (last commit on  2018-08-06)
	(No description available)
\* `gnucash2iif <https://github.com/pawl/gnucash2iif>`__ by pawl (last commit on  2013-08-18)
	Converts a Gnucash general ledger to an IIF file (for quickbooks)
\* `gnucash_autobudget <https://github.com/rmoehn/gnucash_autobudget>`__ by rmoehn (last commit on  2017-03-06)
	Automatically adjust GnuCash transactions for envelope budgeting (discontinued)
\* `gnucash_balance_report <https://github.com/tbhartman/gnucash_balance_report>`__ by tbhartman (last commit on  2014-08-24)
	get balance report from gnucash file
\* `gnucash_budget <https://github.com/dschwen/gnucash_budget>`__ by dschwen (last commit on  2017-01-22)
	Tools to work with a GnuCash database
\* `gnucash_converter <https://github.com/boszkie/gnucash_converter>`__ by boszkie (last commit on  2019-05-05)
	python script to convert rabobank (nl) csv format to gnuCash csv import format
\* `gnucash_django <https://github.com/RobFisher/gnucash_django>`__ by RobFisher (last commit on  2013-05-06)
	GnuCash Web Interface using Django.
`gnucash_envelope_assist <https://github.com/MarkOfLark/gnucash_envelope_assist>`__ by MarkOfLark (last commit on  2020-01-02)
	Scripts that assist in using GnuCash for personal finances under the envelope system
\* `gnucash_explorer <https://github.com/peap/gnucash_explorer>`__ by peap (last commit on  2019-02-13)
	Another option for exploring your gnucash database
\* `gnucash_exports <https://github.com/jjuanda/gnucash_exports>`__ by jjuanda (last commit on  2014-01-13)
	GnuCash export scripts into several DBs/file formats
`gnucash_general_journal <https://github.com/dorfsmay/gnucash_general_journal>`__ by dorfsmay (last commit on  2020-01-20)
	GnuCash csv General Journal
\* `gnucash_import_from_bank <https://github.com/silvester747/gnucash_import_from_bank>`__ by silvester747 (last commit on  2019-08-03)
	Convert bank statements in a format GNUCash can import.
`gnucash_import_util <https://github.com/shinnkondo/gnucash_import_util>`__ by shinnkondo (last commit on  2020-05-16)
	(No description available)
\* `gnucash_invoice_automator <https://github.com/peanutbutterandcrackers/gnucash_invoice_automator>`__ by peanutbutterandcrackers (last commit on  2019-05-05)
	I haz the power of Libreoffice Calc and python-gnucash on my side
\* `gnucash_lbb_amazon <https://github.com/elezar/gnucash_lbb_amazon>`__ by elezar (last commit on  2015-12-28)
	Amazon Credit Card CSV pre-processor for GNUCash
\* `gnucash_magical_importer <https://github.com/foguinhoperuca/gnucash_magical_importer>`__ by foguinhoperuca (last commit on  2019-01-23)
	Set of scripts to manage my personal finance with gnucash
\* `gnucash_ofx <https://github.com/gevious/gnucash_ofx>`__ by gevious (last commit on  2013-01-10)
	Convert gnucash xml file to set of OFX files
\* `gnucash_quotes <https://github.com/belidzs/gnucash_quotes>`__ by belidzs (last commit on  2019-03-01)
	Download stock and currency quotes from Alpha Vantage and save it to GnuCash
\* `gnucash_tweaks <https://github.com/jokim/gnucash_tweaks>`__ by jokim (last commit on  2019-07-29)
	Simple ad hoc tweaks, because I don't have time to learn to code inside GnuCash
\* `gnucashApi <https://github.com/f-angi/gnucashApi>`__ by f-angi (last commit on  2017-12-04)
	(No description available)
\* `GnuCashImporter <https://github.com/sphaero/GnuCashImporter>`__ by sphaero (last commit on  2019-02-25)
	Simple console tool to import mt940 file and match transactions to GnuCash accounts
`gnucashpricesupdater <https://github.com/danfcosta/gnucashpricesupdater>`__ by danfcosta (last commit on  2020-03-31)
	Update prices of Brazilian commodities on GnuCash database (SQLite)
\* `gnucashreconcile <https://github.com/seddonym/gnucashreconcile>`__ by seddonym (last commit on  2017-04-12)
	(No description available)
`gnucashreport <https://github.com/partizand/gnucashreport>`__ by partizand (last commit on  2019-11-08)
	Python library for get reports from GnuCash to xlsx files
\* `GnucashReporting <https://github.com/sholly/GnucashReporting>`__ by sholly (last commit on  2017-06-27)
	Python/Flask backend for gnucash reports
\* `gnucashreports <https://github.com/youngchul/gnucashreports>`__ by youngchul (last commit on  2011-12-06)
	(No description available)
`gnucashREST <https://github.com/f-angi/gnucashREST>`__ by f-angi (last commit on  2020-05-13)
	A REST(ful) API for basic GnuCash operations
\* `GNUCashTools <https://github.com/s8002sid/GNUCashTools>`__ by s8002sid (last commit on  2019-08-13)
	This repository will be used for storing GNUCash tools
\* `gnuCashTools <https://github.com/Walms/gnuCashTools>`__ by Walms (last commit on  2017-07-17)
	Just a few scripts to help manage my budget
\* `GnuCashUtils <https://github.com/wlcasper/GnuCashUtils>`__ by wlcasper (last commit on  2018-12-31)
	GnuCash scripts
\* `gnucashxml <https://github.com/jorgenschaefer/gnucashxml>`__ by jorgenschaefer (last commit on  2017-02-06)
	New Maintainer, please use their repository
\* `hackerspace-gnucash <https://github.com/cvonkleist/hackerspace-gnucash>`__ by cvonkleist (last commit on  2012-08-24)
	Gainesville Hackerspace GnuCash scripts, etc.
\* `importfindata <https://github.com/gregorias/importfindata>`__ by gregorias (last commit on  2017-07-01)
	Script that updates Polish investment fund quotes in a Gnucash file.
\* `ing2gnucash <https://github.com/hjmeijer/ing2gnucash>`__ by hjmeijer (last commit on  2013-07-17)
	Converts downloaded ING (bank) transaction CSV files to GNUCash importable CSV
\* `ing2qif <https://github.com/marijnvriens/ing2qif>`__ by marijnvriens (last commit on  2014-10-18)
	Import ING bank statements and convert them to qif for importing into gnucash
`ing2qif2 <https://github.com/tychobismeijer/ing2qif2>`__ by tychobismeijer (last commit on  2020-09-29)
	Convert ING csv to QIF format for GnuCash
\* `jeffs-gnucash-utils <https://github.com/n1ywb/jeffs-gnucash-utils>`__ by n1ywb (last commit on  2018-12-01)
	Jeff Laughlin's Python utilities for GnuCash. Includes HTML invoice generator.
\* `koert <https://github.com/awesterb/koert>`__ by awesterb (last commit on  2017-07-08)
	Toolbox for the inspection of GnuCash (used by the financial control committee of Karpe Noktem).
`ledger-explorer <https://github.com/saufrecht/ledger-explorer>`__ by saufrecht (last commit on  2020-10-23)
	Navigate any¹ hierarchical ledger graphically, all the way down to individual transactions.  (¹ as long as it's formatted exactly like a Gnucash CSV export)
\* `ledger2gnucash <https://github.com/dotmjs/ledger2gnucash>`__ by dotmjs (last commit on  2016-01-19)
	Simple python script to convert ledger-cli files to GnuCash
\* `mint2gnucash <https://github.com/SAL-e/mint2gnucash>`__ by SAL-e (last commit on  2019-10-06)
	Use mint.com together with GnuCash.
\* `Mint2GNUCash <https://github.com/alexevans91/Mint2GNUCash>`__ by alexevans91 (last commit on  2017-03-04)
	Converts transaction CSV file from Mint.com to a format that can be imported into GNU Cash.
\* `mintcash <https://github.com/hiromu2000/mintcash>`__ by hiromu2000 (last commit on  2019-07-05)
	Transfer transactions from Mint.com to Gnucash
\* `moneyguru-to-gnucash <https://github.com/peppelan/moneyguru-to-gnucash>`__ by peppelan (last commit on  2019-04-21)
	Data migration from Moneyguru to GnuCash made easy
`mwrr <https://github.com/jmtilli/mwrr>`__ by jmtilli (last commit on  2020-08-18)
	Money-weighted rate of return calculator for GnuCash
\* `NokiaCash <https://github.com/sunziping2016/NokiaCash>`__ by sunziping2016 (last commit on  2016-06-01)
	A GnuCash-like software on S60v3 developed by python
`ofxstatement <https://github.com/kedder/ofxstatement>`__ by kedder (last commit on  2020-10-22)
	Tool to convert proprietary bank statement to OFX format, suitable for importing to GnuCash or other personal finance applications.
`ofxstatement-al_bank <https://github.com/lbschenkel/ofxstatement-al_bank>`__ by lbschenkel (last commit on  2020-05-23)
	Arbejdernes Landsbank plugin for ofxstatement
\* `ofxstatement-lansforsakringar <https://github.com/lbschenkel/ofxstatement-lansforsakringar>`__ by lbschenkel (last commit on  2019-03-05)
	Länsförsakringar plugin for ofxstatement
\* `ofxstatement-sparkasse-freiburg <https://github.com/omarkohl/ofxstatement-sparkasse-freiburg>`__ by omarkohl (last commit on  2018-04-04)
	ofxstatement plugin for the German bank Sparkasse Freiburg-Nördlicher Breisgau
\* `pdf2gc <https://github.com/iqt4/pdf2gc>`__ by iqt4 (last commit on  2018-01-06)
	Read bank statement and import into Gnucash
`piecash <https://github.com/sdementen/piecash>`__ by sdementen (last commit on  2020-10-24)
	Pythonic interface to GnuCash SQL documents
\* `pricedb-pull <https://github.com/chrisberkhout/pricedb-pull>`__ by chrisberkhout (last commit on  2018-05-27)
	Pull historical prices for use in GnuCash and Ledger CLI
\* `PyBank <https://github.com/dougthor42/PyBank>`__ by dougthor42 (last commit on  2018-01-20)
	Personal accounting software. Alternative to the likes of Quicken, iBank, Mint.com, and GnuCash
`pygnc <https://github.com/ErwinRieger/pygnc>`__ by ErwinRieger (last commit on  2020-03-22)
	My Gnucash extensions for german small businesses using gnucash and aqbanking python-api's (ibr-gnc-module reloaded).
\* `pygnclib <https://github.com/tdf/pygnclib>`__ by tdf (last commit on  2014-05-26)
	Pyxb-based read and write support for GnuCash XML files
\* `pygnucash <https://github.com/MatzeB/pygnucash>`__ by MatzeB (last commit on  2018-05-12)
	Python code to read gnucash 2.6 sqlite3 files; features gnucash 2 ledger translator.
`pyGnuCash <https://github.com/sebgad/pyGnuCash>`__ by sebgad (last commit on  2020-10-10)
	Python Access for GnuCash
`pyTry <https://github.com/EpistemikPython/pyTry>`__ by EpistemikPython (last commit on  2020-09-18)
	parse Monarch report files and create transactions to write to a Gnucash file
\* `qb2gnc <https://github.com/jfishe/qb2gnc>`__ by jfishe (last commit on  2018-09-28)
	Python 2 convert QuickBooks to GnuCash
\* `qif-split <https://github.com/ebridges/qif-split>`__ by ebridges (last commit on  2018-01-17)
	Splits transactions in a QIF file to support budgeting and more granular financial tracking.
`qifqif <https://github.com/Kraymer/qifqif>`__ by Kraymer (last commit on  2020-07-15)
	Enrich your .QIF files with categories.
`rabo2ofx <https://github.com/gbonnema/rabo2ofx>`__ by gbonnema (last commit on  2019-12-10)
	A python script to convert Dutch Rabobank CSV files to OFX files for processing in GnuCash.
\* `rabobank-gnucash-converter <https://github.com/boterbloem5/rabobank-gnucash-converter>`__ by boterbloem5 (last commit on  2017-12-09)
	(No description available)
\* `scripts <https://github.com/cpg314/scripts>`__ by cpg314 (last commit on  2019-03-24)
	Collection of Python scripts
`simple_gnucash_budget_plots <https://github.com/csun/simple_gnucash_budget_plots>`__ by csun (last commit on  2020-05-21)
	Simple budget plots for GnuCash - discussed in https://www.csun.io/2020/05/17/gnucash-finance.html
\* `skr-json <https://github.com/baltpeter/skr-json>`__ by baltpeter (last commit on  2018-07-17)
	GnuCash account templates (Standard-Kontenrahmen) JSON
`small_scripts <https://github.com/sercxanto/small_scripts>`__ by sercxanto (last commit on  2020-10-18)
	Simple scripts too small for own repo
`square_transaction_parser <https://github.com/rwslippey/square_transaction_parser>`__ by rwslippey (last commit on  2019-11-30)
	A simple script to help prepare square transaction csv data for import to accounting software like GNUCash
\* `text-messaging-to-gnucash <https://github.com/chrisbrasington/text-messaging-to-gnucash>`__ by chrisbrasington (last commit on  2016-01-20)
	Create transactions via commandline text-messaging to gnucash sqlite database.
\* `Timetracker-to-Gnucash-Invoice <https://github.com/EvansMike/Timetracker-to-Gnucash-Invoice>`__ by EvansMike (last commit on  2012-03-15)
	Takes Anuko Timetracker data and creates an Invoice in GnuCash
\* `tws-gnucash <https://github.com/twswn/tws-gnucash>`__ by twswn (last commit on  2012-08-05)
	(No description available)
`UpdateBudgetQtrly <https://github.com/EpistemikPython/UpdateBudgetQtrly>`__ by EpistemikPython (last commit on  2020-09-20)
	gnucash and google functions to update my BudgetQtrly document
\* `visa-parser <https://github.com/pguridi/visa-parser>`__ by pguridi (last commit on  2014-01-08)
	A parser for the Visa pdf bill from www.visa.com.ar, useful for CSV import in Gnucash.
\* `volksbank-csv-to-gnucash-csv-converter <https://github.com/Kaedo/volksbank-csv-to-gnucash-csv-converter>`__ by Kaedo (last commit on  2017-11-05)
	(No description available)
\* `webgnucash <https://github.com/donautech/webgnucash>`__ by donautech (last commit on  2019-09-26)
	Server for web version of GnuCash 
\* `WestpacGNUCashManager <https://github.com/jakeb1996/WestpacGNUCashManager>`__ by jakeb1996 (last commit on  2017-08-20)
	Export your Westpac transactions in QIF format and prepare them for GnuCash
\* `zoysia <https://github.com/honthion/zoysia>`__ by honthion (last commit on  2018-12-22)
	gnucash项目后台 python flask

.. _Awk:

Awk
---

\* `credit-card-statement-reconciler <https://github.com/icyflame/credit-card-statement-reconciler>`__ by icyflame (last commit on  2019-07-27)
	      Scripts to reconcile your credit card statement with your manually maintained accounts from GnuCash
`ibank2qif <https://github.com/tomszilagyi/ibank2qif>`__ by tomszilagyi (last commit on  2020-02-06)
	Bank account transactions into GnuCash

.. _C:

C
-

\* `gnc-balcheck <https://github.com/prebbz/gnc-balcheck>`__ by prebbz (last commit on  2018-02-25)
	Quickly get the balance of a GnuCash which uses a MySQL backend
\* `gnucash-2 <https://github.com/kleopatra999/gnucash-2>`__ by kleopatra999 (last commit on  2011-06-24)
	Yet another clone of the gnucash source code
\* `gnucash-aqplus <https://github.com/jhs-s/gnucash-aqplus>`__ by jhs-s (last commit on  2012-06-24)
	Usually contains some fixes for aqbanking for GnuCash
\* `Gnucash-gnucash <https://github.com/jimmymccord/Gnucash-gnucash>`__ by jimmymccord (last commit on  2018-05-19)
	(No description available)
\* `gnucash-jz-snap <https://github.com/jacobzimmermann/gnucash-jz-snap>`__ by jacobzimmermann (last commit on  2018-08-26)
	(No description available)
\* `gnucash-svn <https://github.com/kleopatra999/gnucash-svn>`__ by kleopatra999 (last commit on  2010-04-08)
	another clone of gnucash, but this time not using github's clone, and therefore keeping the svn metadata
\* `gnucash_python <https://github.com/davidjo/gnucash_python>`__ by davidjo (last commit on  2018-07-20)
	gnucash report writing in python
\* `tk_gnucash3.3-python <https://github.com/tkerns1965/tk_gnucash3.3-python>`__ by tkerns1965 (last commit on  2018-11-30)
	(No description available)

.. _C#:

C#
--

\* `bank2qif <https://github.com/piontec/bank2qif>`__ by piontec (last commit on  2019-08-19)
	A companion project for https://www.gnucash.org/. Helps import bank statements to GnuCash.
`BudgetApp <https://github.com/Lakendary/BudgetApp>`__ by Lakendary (last commit on  2020-02-11)
	Budget web application for GnuCash
\* `CS320GnuCashTesting <https://github.com/BrookJacob/CS320GnuCashTesting>`__ by BrookJacob (last commit on  2018-12-13)
	Repository for the testing of GnuCash for CS320
\* `FinanceWeb <https://github.com/elohmeier/FinanceWeb>`__ by elohmeier (last commit on  2016-07-09)
	C#/.NET OData Adapter for reading GnuCash Databases with MSFT Excel
\* `gnucash2ledger-cli <https://github.com/marek-g/gnucash2ledger-cli>`__ by marek-g (last commit on  2014-08-05)
	Gnucash (general ledger html report) to ledger-cli converter.
`GnuCash2Qif <https://github.com/Jason-Carter/GnuCash2Qif>`__ by Jason-Carter (last commit on  2020-02-02)
	Convert GnuCash Sqlite database to QIF format
\* `GnuCashCSLib <https://github.com/kiranvr/GnuCashCSLib>`__ by kiranvr (last commit on  2018-02-20)
	A C# library to read values from GNUCash xml files.
\* `GnuCashDotNetAPI <https://github.com/SolidDynamics/GnuCashDotNetAPI>`__ by SolidDynamics (last commit on  2019-08-11)
	A .NET API for GnuCash using the C API https://wiki.gnucash.org/wiki/Using_the_API
\* `GnuCashParser <https://github.com/nikitazu/GnuCashParser>`__ by nikitazu (last commit on  2015-02-19)
	.Net parser for GnuCash files format
`GnucashPlDataImportGenerator <https://github.com/AdrianS-PL/GnucashPlDataImportGenerator>`__ by AdrianS-PL (last commit on  2020-10-20)
	(No description available)
\* `GnuCashSharp <https://github.com/rstarkov/GnuCashSharp>`__ by rstarkov (last commit on  2017-07-17)
	A library for reading data from GnuCash XML files.

.. _C++:

C++
---

\* `gnucash-butchered <https://github.com/iulianu/gnucash-butchered>`__ by iulianu (last commit on  2015-03-28)
	My own butchered version of Gnucash
\* `gnuCash-price-upload <https://github.com/gavin-blakeman/gnuCash-price-upload>`__ by gavin-blakeman (last commit on  2018-06-24)
	Upload .csv files to gnuCash prices
\* `gnuCash-pud <https://github.com/gavin-blakeman/gnuCash-pud>`__ by gavin-blakeman (last commit on  2018-08-18)
	Commodity Price Upload Daemon for gnuCash
\* `gnutreemfc <https://github.com/edkirkman/gnutreemfc>`__ by edkirkman (last commit on  2017-11-23)
	gnucash using MFC GUI and MySQL backend
`investmentManager <https://github.com/gavin-blakeman/investmentManager>`__ by gavin-blakeman (last commit on  2020-05-29)
	Web Based Application to complement gnuCash and provide management and user interface to manage mutual funds
\* `UnderBudget <https://github.com/vimofthevine/UnderBudget>`__ by vimofthevine (last commit on  2019-08-05)
	Advanced personal budget analysis application that integrates with GnuCash, Quicken, mint.com, etc.

.. _CSS:

CSS
---

`gnucash_gtk3 <https://github.com/davidschmitt/gnucash_gtk3>`__ by davidschmitt (last commit on  2020-08-22)
	GTK3 CSS for customizing GnuCash appearance

.. _Dart:

Dart
----

`dartcash <https://github.com/sandeep84/dartcash>`__ by sandeep84 (last commit on  2020-08-18)
	Dartlang implementation of GNUCash sqlite format file support.
\* `gnucash-flutter <https://github.com/pefdow/gnucash-flutter>`__ by pefdow (last commit on  2018-09-05)
	Flutter implementation of gnucash-android 
`moneybags <https://github.com/sandeep84/moneybags>`__ by sandeep84 (last commit on  2020-08-10)
	A GNUCash viewer application.

.. _Diff:

Diff
----

\* `GnuCash-Windows-Fixes <https://github.com/theochino/GnuCash-Windows-Fixes>`__ by theochino (last commit on  2015-03-19)
	Pieces needed to Compile Gnu Cash on a Windows machine ... http://wiki.gnucash.org/wiki/User:Bilkusg

.. _Dockerfile:

Dockerfile
----------

`docker-gnucash <https://github.com/mhitchens/docker-gnucash>`__ by mhitchens (last commit on  2020-06-13)
	GnuCash running via X11 over SSH
\* `docker-gnucash <https://github.com/HodeiG/docker-gnucash>`__ by HodeiG (last commit on  2019-07-11)
	docker-gnucash
\* `docker-gnucash <https://github.com/Caveja/docker-gnucash>`__ by Caveja (last commit on  2019-01-03)
	Docker container with GnuCash built from source
\* `docker-gnucash-novnc <https://github.com/bertlorenz/docker-gnucash-novnc>`__ by bertlorenz (last commit on  2018-07-25)
	(No description available)
\* `gnucash-dev-docker <https://github.com/diablodale/gnucash-dev-docker>`__ by diablodale (last commit on  2019-07-23)
	Docker containers for automated OS setup and dev/build environ for gnucash v3+ binaries and docs
`gnucash-docker <https://github.com/aitor3ml/gnucash-docker>`__ by aitor3ml (last commit on  2020-09-28)
	dockerized gnucash
`gnucash-docker <https://github.com/mtbkapp/gnucash-docker>`__ by mtbkapp (last commit on  2020-01-06)
	Run gnucash in docker with tigervnc and novnc for access from browser.
`gnucash-docker <https://github.com/mtbkapp/gnucash-docker>`__ by mtbkapp (last commit on  2020-01-06)
	Run gnucash in docker with tigervnc and novnc for access from browser.
`GNUCash-Docker-Build <https://github.com/crossan007/GNUCash-Docker-Build>`__ by crossan007 (last commit on  2020-02-09)
	Docker based build environment for GNUCash
`gnucash-docker-for-python <https://github.com/devbar/gnucash-docker-for-python>`__ by devbar (last commit on  2019-11-21)
	Container to provide working gnucash backend and python bindings
\* `ppa-gnucash-xbt <https://github.com/msvalina/ppa-gnucash-xbt>`__ by msvalina (last commit on  2019-09-13)
	Unofficial build of GnuCash with Bitcoin support for Ubuntu Bionic

.. _F#:

F#
--

\* `gnucash-tools <https://github.com/cantsin/gnucash-tools>`__ by cantsin (last commit on  2015-11-01)
	(No description available)

.. _Gettext Catalog:

Gettext Catalog
---------------

\* `gnucash-el <https://github.com/pgaval/gnucash-el>`__ by pgaval (last commit on  2015-03-14)
	Automatically exported from code.google.com/p/gnucash-el

.. _Go:

Go
--

`bankcsv <https://github.com/lpenz/bankcsv>`__ by lpenz (last commit on  2019-11-25)
	Tool that I use to convert the CSV from banks to gnucash3-compatible transaction CSV
`coin <https://github.com/mkobetic/coin>`__ by mkobetic (last commit on  2020-09-10)
	heavily simplified version of ledger-cli.org with a twist (very much a work in progress)
\* `gnc-api-d <https://github.com/vinymeuh/gnc-api-d>`__ by vinymeuh (last commit on  2019-07-18)
	A read only REST server for GnuCash file
\* `gnucash-csv-exporter <https://github.com/andrepnh/gnucash-csv-exporter>`__ by andrepnh (last commit on  2018-03-17)
	Exports gnucash files to csv
`gnucash-graphql <https://github.com/vinymeuh/gnucash-graphql>`__ by vinymeuh (last commit on  2020-03-05)
	A GraphQL server for GnuCash files 
\* `gnucash-parser <https://github.com/xavier268/gnucash-parser>`__ by xavier268 (last commit on  2019-09-14)
	Parse Gnucash files in Go
\* `gnucash-viewer <https://github.com/mmbros/gnucash-viewer>`__ by mmbros (last commit on  2017-01-12)
	A gnucash file viewer
\* `gnucash-viewer-old <https://github.com/mmbros/gnucash-viewer-old>`__ by mmbros (last commit on  2016-12-18)
	(No description available)
\* `gocash <https://github.com/remyoudompheng/gocash>`__ by remyoudompheng (last commit on  2013-09-21)
	gocash is a personal accounting interface similar to gnucash
`p24fetch <https://github.com/tuxofil/p24fetch>`__ by tuxofil (last commit on  2020-09-26)
	Fetch transaction log from Privat24 for GnuCash

.. _Groovy:

Groovy
------

\* `Zio-Antunello <https://github.com/masokotanga/Zio-Antunello>`__ by masokotanga (last commit on  2011-09-28)
	un gnucash online (?)

.. _HTML:

HTML
----

\* `Gnucash-gnucash-htdocs <https://github.com/jimmymccord/Gnucash-gnucash-htdocs>`__ by jimmymccord (last commit on  2018-05-19)
	(No description available)
`gnucash-htdocs <https://github.com/Gnucash/gnucash-htdocs>`__ by Gnucash (last commit on  2020-10-22)
	GnuCash website.
\* `gnucash-jp <https://github.com/omoshetech/gnucash-jp>`__ by omoshetech (last commit on  2016-10-07)
	(No description available)
\* `gnucashkr.github.io <https://github.com/GnucashKr/gnucashkr.github.io>`__ by GnucashKr (last commit on  2017-05-10)
	gnucashkr.github.io 홈페이지 소스

.. _Haskell:

Haskell
-------

\* `hGnucash <https://github.com/pharaun/hGnucash>`__ by pharaun (last commit on  2017-12-31)
	Haskell xml library for parsing the gnucash file format
\* `hs-gnucash <https://github.com/knupfer/hs-gnucash>`__ by knupfer (last commit on  2015-07-09)
	Haskell library to work with gnucash

.. _Inno Setup:

Inno Setup
----------

`gnucash-on-windows <https://github.com/Gnucash/gnucash-on-windows>`__ by Gnucash (last commit on  2020-10-18)
	Support scripts to build gnucash for Windows using mingw32.

.. _Java:

Java
----

\* `accounting <https://github.com/milanogc/accounting>`__ by milanogc (last commit on  2016-12-05)
	This project is an attempt to create a GnuCash like system, i.e. it adopts the double entry bookkeeping accounting system, for the management of personal finances.
\* `android_search-recycler-cardview-learning-gnucash <https://github.com/cc-shifo/android_search-recycler-cardview-learning-gnucash>`__ by cc-shifo (last commit on  2017-10-20)
	(No description available)
\* `androidcash <https://github.com/mbarbon/androidcash>`__ by mbarbon (last commit on  2011-08-09)
	Simple Android GnuCash companion
`BackupGnuCashLinux <https://github.com/goodvibes2/BackupGnuCashLinux>`__ by goodvibes2 (last commit on  2020-05-20)
	Backup GnuCash for Linux (using openjdk + openjfx)
`BackupGnuCashMigor <https://github.com/goodvibes2/BackupGnuCashMigor>`__ by goodvibes2 (last commit on  2020-03-11)
	Backup GnuCash + Migor (my personal MS Access database)
`BackupGnuCashWin <https://github.com/goodvibes2/BackupGnuCashWin>`__ by goodvibes2 (last commit on  2020-05-20)
	Backup GnuCash for Windows (using javafx)
\* `barx <https://github.com/pgiu/barx>`__ by pgiu (last commit on  2015-03-05)
	Exportador de la información del estado de cuenta de Banco Galicia a CSV/QIF para usar en MoneyManagerEx, GnuCash, etc.
\* `barxm <https://github.com/pgiu/barxm>`__ by pgiu (last commit on  2015-03-06)
	Exportador de la información del estado de cuenta de Banco Galicia a CSV/QIF para usar en MoneyManagerEx, GnuCash, etc.
\* `BudgetReportGnuCash <https://github.com/martinlong1978/BudgetReportGnuCash>`__ by martinlong1978 (last commit on  2011-04-08)
	Jasper Budget Report for GnuCash
\* `convert-ingcsv-to-gnucash <https://github.com/jonaskoperdraat/convert-ingcsv-to-gnucash>`__ by jonaskoperdraat (last commit on  2016-06-12)
	Application to convert csv export from ING to a format GnuCash can import
\* `gcchart <https://github.com/jhogan/gcchart>`__ by jhogan (last commit on  2015-06-14)
	An website for reading GnuCash datasources and creating charts written in Java.
\* `gnc4a <https://github.com/bwduncan/gnc4a>`__ by bwduncan (last commit on  2011-01-16)
	GnuCash Companion for Android is an mobile application for devices running Google’s Android operating system, which will enable the users of GnuCash to do small things like adding a transaction or creating an invoice or expense voucher on the go.
\* `gnc4a <https://github.com/glennji/gnc4a>`__ by glennji (last commit on  2012-05-06)
	Gnucash for Android
\* `GncImport <https://github.com/fcuenca/GncImport>`__ by fcuenca (last commit on  2018-07-08)
	GnuCash transaction import tool
\* `GncXmlLib <https://github.com/fcuenca/GncXmlLib>`__ by fcuenca (last commit on  2015-12-05)
	A small library to manipulate GnuCash data in XML format
\* `GnuCash-2.6.5-importer <https://github.com/jan438/GnuCash-2.6.5-importer>`__ by jan438 (last commit on  2015-02-02)
	(No description available)
`gnucash-android <https://github.com/codinguser/gnucash-android>`__ by codinguser (last commit on  2020-07-21)
	Gnucash for Android mobile companion application. 
`gnucash-android <https://github.com/BattleCupcake/gnucash-android>`__ by BattleCupcake (last commit on  2020-09-25)
	(No description available)
`gnucash-android <https://github.com/yjkang0602/gnucash-android>`__ by yjkang0602 (last commit on  2020-03-31)
	(No description available)
`gnucash-android <https://github.com/yjkang0602/gnucash-android>`__ by yjkang0602 (last commit on  2020-03-31)
	(No description available)
`gnucash-android <https://github.com/nicxleo/gnucash-android>`__ by nicxleo (last commit on  2020-05-02)
	(No description available)
\* `gnucash-android-example <https://github.com/felipecmuniz/gnucash-android-example>`__ by felipecmuniz (last commit on  2018-05-28)
	(No description available)
\* `gnucash-merge <https://github.com/pnemonic78/gnucash-merge>`__ by pnemonic78 (last commit on  2017-08-16)
	Merge two gnucash XML files.
\* `gnucash-utils <https://github.com/crankydillo/gnucash-utils>`__ by crankydillo (last commit on  2019-08-31)
	(No description available)
`gnuCashAdaptors <https://github.com/yrado/gnuCashAdaptors>`__ by yrado (last commit on  2020-05-23)
	Scripts to make import to GnuCash simple
\* `GnuCashBudgetReport <https://github.com/bvitale/GnuCashBudgetReport>`__ by bvitale (last commit on  2012-01-21)
	A budget report for GnuCash data that is stored in MySQL.
\* `gnucashjgnash <https://github.com/leeboardtools/gnucashjgnash>`__ by leeboardtools (last commit on  2018-01-23)
	Plugin for jGnash that converts a (simple) GnuCash database to jGnash
\* `gnucashMobile <https://github.com/nhrdl/gnucashMobile>`__ by nhrdl (last commit on  2013-10-19)
	(No description available)
\* `gnuCashN <https://github.com/nyshthefantastic/gnuCashN>`__ by nyshthefantastic (last commit on  2017-10-16)
	(No description available)
\* `gnucashtest <https://github.com/krismess/gnucashtest>`__ by krismess (last commit on  2019-09-26)
	Automated test for Gnucash Android app
\* `GnuCashToQIF <https://github.com/davidkgerman/GnuCashToQIF>`__ by davidkgerman (last commit on  2011-12-11)
	(No description available)
\* `GnuCashViewer <https://github.com/jrmcsoftware/GnuCashViewer>`__ by jrmcsoftware (last commit on  2014-03-03)
	GnuCash Viewer
`IngAusOfxFixLinux <https://github.com/goodvibes2/IngAusOfxFixLinux>`__ by goodvibes2 (last commit on  2020-03-11)
	ING Australia OFX Fix for Linux - Fix OFX file before importing into GnuCash
`IngAusOfxFixWin <https://github.com/goodvibes2/IngAusOfxFixWin>`__ by goodvibes2 (last commit on  2020-03-11)
	ING Australia OFX Fix for Windows - Fix OFX file before importing into GnuCash
\* `javacash <https://github.com/nhrdl/javacash>`__ by nhrdl (last commit on  2013-08-09)
	Yet another implementation of gnucash in Java
`javacash <https://github.com/brentwalther/javacash>`__ by brentwalther (last commit on  2020-10-13)
	An application for managing money. Inspired by GnuCash.
\* `jgc <https://github.com/kevemueller/jgc>`__ by kevemueller (last commit on  2018-06-11)
	Java library to read GnuCash files
`jGnuCash2Qif <https://github.com/Jason-Carter/jGnuCash2Qif>`__ by Jason-Carter (last commit on  2019-10-27)
	Convert GnuCash Sqlite database to QIF format - the Java version
\* `jgnucashlib <https://github.com/tdf/jgnucashlib>`__ by tdf (last commit on  2012-07-10)
	jGnucashLib - a java access to GnuCash files
`Maakboekingen <https://github.com/zwijze/Maakboekingen>`__ by zwijze (last commit on  2020-10-13)
	Maakboekingen in gnucash
\* `nordea-to-gnucash <https://github.com/mohamedamer/nordea-to-gnucash>`__ by mohamedamer (last commit on  2013-12-08)
	(No description available)
\* `workspace_gnucash <https://github.com/won21kr1/workspace_gnucash>`__ by won21kr1 (last commit on  2014-04-16)
	(No description available)

.. _JavaScript:

JavaScript
----------

\* `bcqif <https://github.com/hugozap/bcqif>`__ by hugozap (last commit on  2015-09-23)
	Script simple para generar archivos QIF a partir de archivos .txt exportados desde Bancolombia y poder cargar los registros a programas como GnuCash
`cash-cow <https://github.com/Lkxz/cash-cow>`__ by Lkxz (last commit on  2020-06-30)
	A basic double-entry bookeping system, similar to GNUCash, written in Go and React.
`cashdash <https://github.com/mbugert/cashdash>`__ by mbugert (last commit on  2020-03-22)
	💰 Interactive visualization of GnuCash data based on plotly Dash.
\* `cashviz <https://github.com/nunofgl/cashviz>`__ by nunofgl (last commit on  2017-12-28)
	Visualizations for GNUCash data.
\* `finance_dashboard <https://github.com/manicolosi/finance_dashboard>`__ by manicolosi (last commit on  2014-03-09)
	A dashing dashboard to show financial information from GnuCash
\* `finquick <https://github.com/dckc/finquick>`__ by dckc (last commit on  2018-10-04)
	web app access to gnucash financial data
`gnucash-browser <https://github.com/phjardas/gnucash-browser>`__ by phjardas (last commit on  2020-10-20)
	Web Interface for GnuCash Ledgers
\* `gnucash-django <https://github.com/nylen/gnucash-django>`__ by nylen (last commit on  2015-11-20)
	Simple Web frontend for GnuCash, using Django
\* `gnucash-ext <https://github.com/matthewbednarski/gnucash-ext>`__ by matthewbednarski (last commit on  2015-05-30)
	(No description available)
`gnucash-ppa <https://github.com/chenghlee/gnucash-ppa>`__ by chenghlee (last commit on  2020-04-19)
	Sources for the chenghlee/gnucash PPA
\* `gnucash-price-importer <https://github.com/cortopy/gnucash-price-importer>`__ by cortopy (last commit on  2018-05-05)
	Script for importing historic currency prices into gnucash
\* `gnucash-reporter <https://github.com/AaronLenoir/gnucash-reporter>`__ by AaronLenoir (last commit on  2017-03-06)
	Visualizes some reports on GnuCash data.
\* `gnucash-reporting-view <https://github.com/MeerkatLabs/gnucash-reporting-view>`__ by MeerkatLabs (last commit on  2018-04-24)
	Angular JS Based viewer for gnucash-reports
`gnucash-sql <https://github.com/wraithgar/gnucash-sql>`__ by wraithgar (last commit on  2020-07-04)
	Gnucash sqlite thingy
\* `gnucash-viewer <https://github.com/drjeep/gnucash-viewer>`__ by drjeep (last commit on  2013-07-19)
	Web viewer for Gnucash using Python/Flask
\* `gnucash-web <https://github.com/mrkrstphr/gnucash-web>`__ by mrkrstphr (last commit on  2013-06-17)
	(No description available)
\* `GnucashReportingNVD3 <https://github.com/sholly/GnucashReportingNVD3>`__ by sholly (last commit on  2017-07-04)
	NVD3 frontend/playground for gnucash reporting..
`monalyzer <https://github.com/Vlad-ku/monalyzer>`__ by Vlad-ku (last commit on  2020-03-13)
	Анализ файлов QIF (GnuCash)
\* `profitcash-restful <https://github.com/TheProfitwareGroup/profitcash-restful>`__ by TheProfitwareGroup (last commit on  2012-09-16)
	[DEPRECATED] ProfitCash-RESTful is a RESTful service providing accounts and transaction information based on imported from GnuCash into MongoDB data.
`qif-converter <https://github.com/matthijsmelissen/qif-converter>`__ by matthijsmelissen (last commit on  2020-09-07)
	Converts CSV files from ING (Netherlands) and BCEE (Luxembourg) into QIF files. Suitable for GnuCash.
\* `remotegnucash <https://github.com/justinhunt1223/remotegnucash>`__ by justinhunt1223 (last commit on  2017-04-17)
	Remote GnuCash
\* `salis <https://github.com/f0x52/salis>`__ by f0x52 (last commit on  2018-04-05)
	GNUCash alternative
\* `skilap <https://github.com/sergeyksv/skilap>`__ by sergeyksv (last commit on  2017-06-26)
	Personal online applications, GnuCash clone and others
`vue-gnucash <https://github.com/biker2000on/vue-gnucash>`__ by biker2000on (last commit on  2020-09-08)
	(No description available)
`webgnucash-client <https://github.com/donautech/webgnucash-client>`__ by donautech (last commit on  2020-09-10)
	Client part of Web version of GnuCash

.. _Jupyter Notebook:

Jupyter Notebook
----------------

`gnucash-historical-price-data <https://github.com/MichaelSchmidt82/gnucash-historical-price-data>`__ by MichaelSchmidt82 (last commit on  2020-04-10)
	Add historical stock price data to gnucash ledgers.
\* `gnucash-playground <https://github.com/nlzimmerman/gnucash-playground>`__ by nlzimmerman (last commit on  2016-08-15)
	Just playing around with OFX and gnucash files; I am presumably the only person who cares about this sort of things.
\* `gnucash_analysis <https://github.com/prattmic/gnucash_analysis>`__ by prattmic (last commit on  2018-12-22)
	Analyze GnuCash data with Pandas
`GnuCash_tools <https://github.com/PingWIn87/GnuCash_tools>`__ by PingWIn87 (last commit on  2020-09-23)
	My toolset for GnuCash
\* `py-gnucash <https://github.com/ihkihk/py-gnucash>`__ by ihkihk (last commit on  2017-05-17)
	Python scripts for analysis of gnucash database

.. _PHP:

PHP
---

\* `buchungen <https://github.com/jungepiraten/buchungen>`__ by jungepiraten (last commit on  2016-05-26)
	Webinterface für gnucash-Datenbank mit Funktion zum Verifizieren von Buchungen
\* `cash-manager <https://github.com/jUnG3/cash-manager>`__ by jUnG3 (last commit on  2017-02-18)
	(No description available)
\* `cashonline-php-server <https://github.com/okovalov/cashonline-php-server>`__ by okovalov (last commit on  2014-10-31)
	Backend part for cashonline project (clone of gnucash)
\* `gnucash-dashboard <https://github.com/bkrijg/gnucash-dashboard>`__ by bkrijg (last commit on  2017-12-28)
	(No description available)
\* `gnucash-eloquent <https://github.com/b3it/gnucash-eloquent>`__ by b3it (last commit on  2016-05-31)
	Laravel Eloquent Models for the GnuCash MySQL Backend
\* `gnucash-laravel <https://github.com/xstat/gnucash-laravel>`__ by xstat (last commit on  2015-12-21)
	(No description available)
\* `gnucash-php <https://github.com/cebe/gnucash-php>`__ by cebe (last commit on  2014-08-04)
	A library for reading gnucash XML format in PHP
\* `gnucash-reports <https://github.com/xstat/gnucash-reports>`__ by xstat (last commit on  2017-07-30)
	(No description available)
\* `gnucash-tools <https://github.com/cccmzwi/gnucash-tools>`__ by cccmzwi (last commit on  2013-12-16)
	Convert your onlinebanking-export (CSV) to a neatly pre-categorized QIF-File which can be imported in Quicken or Gnucash
\* `gnucash.cakephp <https://github.com/claudineimatos/gnucash.cakephp>`__ by claudineimatos (last commit on  2014-06-25)
	(No description available)
\* `gnucashreports <https://github.com/pedroabel/gnucashreports>`__ by pedroabel (last commit on  2013-02-08)
	Set of custom reports that I use for my personal finances. To see the reports working on a sample database, check the website http://gnucashreports.comuf.com/ ATTENTION: many problems yet. Many bugs that did not happen in my computer happened in this sample server.
\* `php-gnucash <https://github.com/mrkrstphr/php-gnucash>`__ by mrkrstphr (last commit on  2013-06-17)
	(No description available)
`PhpGnuCashMatchTransactions <https://github.com/puggan/PhpGnuCashMatchTransactions>`__ by puggan (last commit on  2019-10-31)
	Tool for GnuCash databases, to import and match up transactions from banks export-files
\* `plans-comptables-francais <https://github.com/Seb35/plans-comptables-francais>`__ by Seb35 (last commit on  2019-04-17)
	Plans comptables français aux formats CSV et GNUCash
\* `ThinkopenAt.Gnucash <https://github.com/kraftb/ThinkopenAt.Gnucash>`__ by kraftb (last commit on  2018-01-12)
	A TYPO3 Flow package which allows to interface the Gnucash book keeping application
`txs <https://github.com/vvvitaly/txs>`__ by vvvitaly (last commit on  2019-11-07)
	Export bills from different sources into Gnucash-like CSV

.. _PLSQL:

PLSQL
-----

`gnucash-mysql-additions <https://github.com/ohingardail/gnucash-mysql-additions>`__ by ohingardail (last commit on  2019-11-02)
	Custom MySql functions to add useful functions to GnuCash

.. _Perl:

Perl
----

\* `bsestocks <https://github.com/poomalairaj/bsestocks>`__ by poomalairaj (last commit on  2017-06-07)
	Perl module to fetch live price from Bombay Stock Exchange (BSE) for Gnucash Finance
\* `budgetProgram <https://github.com/Beahmer89/budgetProgram>`__ by Beahmer89 (last commit on  2016-10-23)
	Converts GNUCash programs xml output to csv file to see monthly/yearly spending habits
`Finance--Quote--YahooJapan <https://github.com/LiosK/Finance--Quote--YahooJapan>`__ by LiosK (last commit on  2020-01-26)
	Finance::Quote::YahooJapan - A Perl module that enables GnuCash to get quotes of Japanese stocks and mutual funds from Yahoo! Finance JAPAN.
\* `finance-bomse <https://github.com/abhijit86k/finance-bomse>`__ by abhijit86k (last commit on  2017-11-06)
	A Perl module for fetching quotes for Indian stocks, intended for use with gnucash
\* `finance-quote-brazil <https://github.com/romuloceccon/finance-quote-brazil>`__ by romuloceccon (last commit on  2018-06-15)
	Gnucash/Finance::Quote modules to fetch prices of Brazilian stocks, bonds and mutual funds
\* `FinanceQuoteBr <https://github.com/ailtonljr/FinanceQuoteBr>`__ by ailtonljr (last commit on  2017-09-08)
	Perl Finance Quote modules for Brazilian market. Original files from https://lists.gnucash.org/pipermail/gnucash-br/2016-November/000535.html
\* `gc2latex <https://github.com/wertarbyte/gc2latex>`__ by wertarbyte (last commit on  2011-02-25)
	create pretty Gnucash invoices with LaTeX and Perl
\* `GnuCash-Branch <https://github.com/LiosK/GnuCash-Branch>`__ by LiosK (last commit on  2015-04-26)
	GnuCash::Branch - Utilities to implement branch accounting with GnuCash.
\* `gnucash-extensions <https://github.com/tomason/gnucash-extensions>`__ by tomason (last commit on  2017-08-02)
	(No description available)
\* `gnucash-monthly-budget-report <https://github.com/mhodapp/gnucash-monthly-budget-report>`__ by mhodapp (last commit on  2015-03-01)
	perl program to generate monthly budget reports
\* `GnuCash-MySQL <https://github.com/theochino/GnuCash-MySQL>`__ by theochino (last commit on  2015-03-18)
	A MySQL module to Gnu Cash
\* `gnucash-perl <https://github.com/goblin/gnucash-perl>`__ by goblin (last commit on  2011-01-29)
	Perl modules for reading and writing the Gnucash XML file
\* `gnucash-quote-sources <https://github.com/tjol/gnucash-quote-sources>`__ by tjol (last commit on  2017-04-23)
	Some useful methods to fetch market price data for GnuCash
\* `GnuCash-SQLite <https://github.com/hoekit/GnuCash-SQLite>`__ by hoekit (last commit on  2015-05-20)
	A perl module to access GnuCash SQLite files.
\* `GnuCash-SQLite <https://github.com/gitpan/GnuCash-SQLite>`__ by gitpan (last commit on  2015-01-08)
	Read-only release history for GnuCash-SQLite
\* `gnucash-summarizer <https://github.com/Nazrax/gnucash-summarizer>`__ by Nazrax (last commit on  2016-05-06)
	(No description available)
`gnucash-xml-to-ledger-dat <https://github.com/icyflame/gnucash-xml-to-ledger-dat>`__ by icyflame (last commit on  2020-02-11)
	A script to convert GNUCash's XML file to Ledger's dat file
\* `gnucash2mysql <https://github.com/xaprb/gnucash2mysql>`__ by xaprb (last commit on  2014-01-18)
	Gnucash to MySQL export script.
\* `gnucash2mysql_extras <https://github.com/hmackiernan/gnucash2mysql_extras>`__ by hmackiernan (last commit on  2018-12-23)
	Extra scripts and bits for gnucash2mysql
\* `gnuCash_Quote <https://github.com/z-Wind/gnuCash_Quote>`__ by z-Wind (last commit on  2016-01-06)
	modify perl\site\lib\Finance\Quote.pm
\* `MoneyDance-GnuCash-Importer <https://github.com/ets/MoneyDance-GnuCash-Importer>`__ by ets (last commit on  2015-10-31)
	Script to convert GnuCash data into a native MoneyDance XML file format
\* `Paypal-csv-to-qif-converter <https://github.com/sonologic/Paypal-csv-to-qif-converter>`__ by sonologic (last commit on  2011-05-04)
	Converts paypal .csv to qif for importing in gnucash
\* `perl-gnucash-reader <https://github.com/hoekit/perl-gnucash-reader>`__ by hoekit (last commit on  2014-06-14)
	(No description available)
`PerlFinanceQuoteBloomberg <https://github.com/alex314159/PerlFinanceQuoteBloomberg>`__ by alex314159 (last commit on  2020-07-01)
	Bloomberg module for the Perl Finance::Quote module (used in particular by GnuCash)
\* `query_gnucash_db <https://github.com/hmackiernan/query_gnucash_db>`__ by hmackiernan (last commit on  2016-08-20)
	Perl script to query a MySQL db created by the 'gnucash2mysql' script

.. _Perl6:

Perl6
-----

\* `perl6-gnucash <https://github.com/eikef/perl6-gnucash>`__ by eikef (last commit on  2016-08-24)
	Use gnucash library from Perl 6

.. _R:

R
-

`gnucashAndR <https://github.com/mrop/gnucashAndR>`__ by mrop (last commit on  2020-07-23)
	(No description available)
\* `ShinyBudgetAnalysis <https://github.com/paulheider/ShinyBudgetAnalysis>`__ by paulheider (last commit on  2017-04-06)
	A Shiny app (R-based dashboard) that gives insight into your GnuCash budget habits over time.

.. _Roff:

Roff
----

\* `gnucash-docker <https://github.com/rusodavid/gnucash-docker>`__ by rusodavid (last commit on  2019-04-20)
	(No description available)

.. _Ruby:

Ruby
----

\* `accounting <https://github.com/freegeek-pdx/accounting>`__ by freegeek-pdx (last commit on  2013-11-18)
	accounting utilities for xtuple import and allocation in xtuple and gnucash
\* `arges <https://github.com/isimluk/arges>`__ by isimluk (last commit on  2016-12-31)
	Calc roe from gnucash transaction log
\* `banks-to-gnucash <https://github.com/toniprada/banks-to-gnucash>`__ by toniprada (last commit on  2019-01-10)
	Quaterly bank reports in CSV GnuCash-friendly format directly in your email.
`boekhouden-met-gnucash <https://github.com/mauritslamers/boekhouden-met-gnucash>`__ by mauritslamers (last commit on  2020-05-21)
	Een Nederlandse handleiding over het boekhouden met GnuCash
\* `cnab2ofx <https://github.com/abinoam/cnab2ofx>`__ by abinoam (last commit on  2016-01-04)
	CNAB240 to OFX conversion script
\* `dnbnor2qif <https://github.com/kentdahl/dnbnor2qif>`__ by kentdahl (last commit on  2016-09-21)
	dnbnor2qif is a simple tool to help integrate data from the DnBNOR online bank monthly transcripts ("kontoutskrift") to a QIF accepting financial program, i.e. GnuCash.
\* `equity_flow <https://github.com/fernandors87/equity_flow>`__ by fernandors87 (last commit on  2018-07-20)
	A personal asset management software
\* `gnucash-invoice <https://github.com/ixti/gnucash-invoice>`__ by ixti (last commit on  2018-07-28)
	Easy to use invoice printer for GnuCash.
\* `gnucash-rb <https://github.com/vbatts/gnucash-rb>`__ by vbatts (last commit on  2012-07-11)
	Ruby access to Gnucash SQL database
\* `gnucash-summarizer <https://github.com/arthurljones/gnucash-summarizer>`__ by arthurljones (last commit on  2019-01-10)
	(No description available)
\* `gnucash2bmd <https://github.com/ngiger/gnucash2bmd>`__ by ngiger (last commit on  2017-05-30)
	Convert GnuCash CSV files into CSV which can be read by http://www.bmd.com/
\* `gnucash2ledger <https://github.com/xaviershay/gnucash2ledger>`__ by xaviershay (last commit on  2016-09-28)
	Convert GnuCash files to a format supported by the ledger command line application
\* `gnucash_export <https://github.com/alibby/gnucash_export>`__ by alibby (last commit on  2009-10-26)
	Export gnucash data to sqlite/ csv
\* `gnucash_getquotes <https://github.com/hubcity/gnucash_getquotes>`__ by hubcity (last commit on  2018-03-14)
	(No description available)
`rcash <https://github.com/salex/rcash>`__ by salex (last commit on  2020-10-21)
	Rails Double Entry Accounting app patterned after GNUCash
`ruby-gnucash <https://github.com/holtrop/ruby-gnucash>`__ by holtrop (last commit on  2020-02-25)
	Ruby library for extracting data from GnuCash data files
\* `vfwcash <https://github.com/salex/vfwcash>`__ by salex (last commit on  2018-09-06)
	A Ruby CLI application that produces PDF reports from GnuCash

.. _Rust:

Rust
----

`stay-the-course <https://github.com/DavidCain/stay-the-course>`__ by DavidCain (last commit on  2020-09-22)
	Lazy portfolio rebalancer for GnuCash users

.. _SQLPL:

SQLPL
-----

\* `gnucash-tools <https://github.com/schoettl/gnucash-tools>`__ by schoettl (last commit on  2017-07-05)
	Collection of tools to work with GnuCash efficiently

.. _Scala:

Scala
-----

\* `gnucash-stuff <https://github.com/crankydillo/gnucash-stuff>`__ by crankydillo (last commit on  2011-12-30)
	(No description available)
\* `GnuCashExtractor <https://github.com/Winbee/GnuCashExtractor>`__ by Winbee (last commit on  2015-08-12)
	Extract data from gnuCash and copy it into an open document spreadsheet
`YNAB4toGnuCashMigrationTool <https://github.com/galbarm/YNAB4toGnuCashMigrationTool>`__ by galbarm (last commit on  2020-02-18)
	YNAB 4 to GnuCash Migration Tool

.. _Scheme:

Scheme
------

\* `bas-report <https://github.com/spandan888/bas-report>`__ by spandan888 (last commit on  2017-08-11)
	GST India Report / Business Tax Report
\* `gc-decl-reports <https://github.com/yawaramin/gc-decl-reports>`__ by yawaramin (last commit on  2014-02-09)
	GnuCash declarative reports
\* `gnucash-account-balance-chart <https://github.com/timabell/gnucash-account-balance-chart>`__ by timabell (last commit on  2009-04-11)
	account balance line chart for gnucash
\* `gnucash-custom-reports <https://github.com/BenBergman/gnucash-custom-reports>`__ by BenBergman (last commit on  2018-07-11)
	(No description available)
\* `gnucash-multicolumn <https://github.com/daniel-beet/gnucash-multicolumn>`__ by daniel-beet (last commit on  2017-09-18)
	Advanced date and text filtering and multicolumn reports
\* `gnucash-paypal-invoice-template <https://github.com/charlesmulder/gnucash-paypal-invoice-template>`__ by charlesmulder (last commit on  2018-06-20)
	GnuCash invoice template that resembles a PayPal invoice
\* `gnucash-reports <https://github.com/dschwen/gnucash-reports>`__ by dschwen (last commit on  2016-01-27)
	Custom reports for Gnucash
\* `gnucash-reports <https://github.com/trailbound/gnucash-reports>`__ by trailbound (last commit on  2012-08-03)
	Custom set of gnucash reports, currently in development.
\* `gnucash-reports <https://github.com/cnuahs/gnucash-reports>`__ by cnuahs (last commit on  2015-12-29)
	Custom reports for use with GnuCash (http://gnucash.org/).
`gnucash-reports <https://github.com/jaminh/gnucash-reports>`__ by jaminh (last commit on  2020-08-06)
	Reports for personal finance using gnucash
\* `gnucash-reports <https://github.com/wentzel/gnucash-reports>`__ by wentzel (last commit on  2016-11-14)
	Some nice reports for GnuCash
\* `gnucash-statement-table <https://github.com/waldeinburg/gnucash-statement-table>`__ by waldeinburg (last commit on  2016-01-13)
	GnuCash report with cash flow over time
\* `gnucashportable <https://github.com/GordCaswell/gnucashportable>`__ by GordCaswell (last commit on  2016-12-20)
	GnuCash packaged in PortableApps.com Format
\* `GnuCashReports <https://github.com/wlcasper/GnuCashReports>`__ by wlcasper (last commit on  2018-03-03)
	Custom Reports for GnuCash
`ibr-gnc-module <https://github.com/ErwinRieger/ibr-gnc-module>`__ by ErwinRieger (last commit on  2020-03-28)
	GnuCash Erweiterungen für deutsche Buchhaltung

.. _Shell:

Shell
-----

\* `AccountsConvertToGnucash <https://github.com/tontako/AccountsConvertToGnucash>`__ by tontako (last commit on  2016-12-23)
	Convert Kakeibo(Android Application) CSV exports to QIF format (usable by GnuCash and others) 
`ansible-role-gnucash <https://github.com/alvistack/ansible-role-gnucash>`__ by alvistack (last commit on  2020-10-21)
	Ansible Role for GnuCash Installation
\* `archlinux-gnucash-latest <https://github.com/nengxu/archlinux-gnucash-latest>`__ by nengxu (last commit on  2015-03-31)
	Archlinux AUR package building scripts for latest Gnucash
\* `docker_gnucash <https://github.com/tkerns1965/docker_gnucash>`__ by tkerns1965 (last commit on  2018-01-19)
	(No description available)
\* `docker_gnucash_novnc <https://github.com/tkerns1965/docker_gnucash_novnc>`__ by tkerns1965 (last commit on  2018-01-25)
	(No description available)
\* `gnucash-build <https://github.com/hanulhan/gnucash-build>`__ by hanulhan (last commit on  2018-02-20)
	(No description available)
\* `gnucash-build-script <https://github.com/z-Wind/gnucash-build-script>`__ by z-Wind (last commit on  2019-03-08)
	for ubuntu 
\* `gnucash-csv-import <https://github.com/thomasramapuram/gnucash-csv-import>`__ by thomasramapuram (last commit on  2016-08-08)
	(No description available)
\* `gnucash-devel <https://github.com/aur-archive/gnucash-devel>`__ by aur-archive (last commit on  2015-08-15)
	(No description available)
\* `gnucash-docker <https://github.com/limitedAtonement/gnucash-docker>`__ by limitedAtonement (last commit on  2017-01-27)
	docker image for repeatable gnucash builds.
\* `gnucash-docs <https://github.com/aur-archive/gnucash-docs>`__ by aur-archive (last commit on  2015-08-15)
	(No description available)
\* `gnucash-docs-old <https://github.com/yasuakit/gnucash-docs-old>`__ by yasuakit (last commit on  2011-09-24)
	Manual and User Guide for Gnucash, the open-source accounting program
\* `gnucash-hbci <https://github.com/aur-archive/gnucash-hbci>`__ by aur-archive (last commit on  2015-08-15)
	(No description available)
\* `gnucash-on-debian <https://github.com/rayelnigma/gnucash-on-debian>`__ by rayelnigma (last commit on  2018-09-16)
	a set of build scripts to build gnucash using Ninja for faster builds
\* `gnucash-on-fedora-copr <https://github.com/zhiqinghuang/gnucash-on-fedora-copr>`__ by zhiqinghuang (last commit on  2015-10-29)
	A set of build scripts geared towards creating rpm packages for gnucash and gnucash-docs on Fedora's Copr infrastructure. It's currently used to build nightly rpm packages for the maint and master branches intended for testing changes since the last release..
`gnucash-on-flatpak <https://github.com/Gnucash/gnucash-on-flatpak>`__ by Gnucash (last commit on  2020-10-15)
	Packaging scripts to generate flatpaks directly from gnucash and gnucash-docs git repositories
`gnucash-on-osx <https://github.com/Gnucash/gnucash-on-osx>`__ by Gnucash (last commit on  2020-10-03)
	Gtk-OSX moduleset, gtk-mac-bundler bundles, and ancillary files for creating GnuCash OSX Application Bundle.
`gnucash-on-osx <https://github.com/jralls/gnucash-on-osx>`__ by jralls (last commit on  2020-07-12)
	Build GnuCash on OSX without X11
\* `gnucash-python <https://github.com/aur-archive/gnucash-python>`__ by aur-archive (last commit on  2015-08-15)
	(No description available)
\* `gnucash-svn <https://github.com/aur-archive/gnucash-svn>`__ by aur-archive (last commit on  2015-08-15)
	(No description available)
`gnucash-util-jp <https://github.com/mikkun/gnucash-util-jp>`__ by mikkun (last commit on  2020-08-09)
	日本の商慣習下でGnuCashを使うためのツール
`gnucash.AppImage <https://github.com/ecmu/gnucash.AppImage>`__ by ecmu (last commit on  2020-04-12)
	AppImage build for gnucash
\* `gnucash.SlackBuild <https://github.com/botzkobg/gnucash.SlackBuild>`__ by botzkobg (last commit on  2015-04-02)
	SlackBuild script to compile GnuCash
\* `LittleBudget <https://github.com/kstripp/LittleBudget>`__ by kstripp (last commit on  2012-06-17)
	Little Budget Tool for GNUCash
\* `nordea2ofx <https://github.com/nsrosenqvist/nordea2ofx>`__ by nsrosenqvist (last commit on  2014-10-24)
	A quick implementation of a converter between Nordea's CSV export to OFX so that it can be imported into various applications, such as Homebank or GnuCash. Only supporting Swedish and my edge cases, please consider improving the script and send a pull request for the changes.
\* `TW5-GNUCash-Assistant <https://github.com/JulioCantarero/TW5-GNUCash-Assistant>`__ by JulioCantarero (last commit on  2016-03-12)
	A custom edition of TiddlyWiki5 designed to collect financial information from your banks and export them in QIF format

.. _Swift:

Swift
-----

\* `cash <https://github.com/cjwirth/cash>`__ by cjwirth (last commit on  2017-07-03)
	iOS companion app for GnuCash

.. _TSQL:

TSQL
----

`gnucash-reports <https://github.com/fredzica/gnucash-reports>`__ by fredzica (last commit on  2020-01-12)
	Custom reports that use data from gnucash's SQL database
\* `GNUCashProcs <https://github.com/nicholasceliano/GNUCashProcs>`__ by nicholasceliano (last commit on  2019-10-22)
	(No description available)

.. _Tcl:

Tcl
---

\* `pycash <https://github.com/davinirjr/pycash>`__ by davinirjr (last commit on  2015-01-25)
	Some Python utilites that GnuCash users may find useful.

.. _TypeScript:

TypeScript
----------

`gnucash-global-importer <https://github.com/klodzack/gnucash-global-importer>`__ by klodzack (last commit on  2020-09-10)
	(No description available)
`gnucash-graphql <https://github.com/phjardas/gnucash-graphql>`__ by phjardas (last commit on  2020-07-17)
	GraphQL Wrapper For GnuCash Ledgers
`GnuCashImporter <https://github.com/nicholasceliano/GnuCashImporter>`__ by nicholasceliano (last commit on  2020-07-19)
	(No description available)
`v9-geckos-team-07 <https://github.com/chingu-voyages/v9-geckos-team-07>`__ by chingu-voyages (last commit on  2020-09-05)
	GeckoCash: A web-based GnuCash clone.
\* `web-cash <https://github.com/ashishmondal/web-cash>`__ by ashishmondal (last commit on  2017-06-29)
	Web version of GnuCash
\* `web-cash <https://github.com/ashishmondal/web-cash>`__ by ashishmondal (last commit on  2017-06-29)
	Web version of GnuCash

.. _Visual Basic:

Visual Basic
------------

\* `OneClickToQif <https://github.com/OneClickToQif/OneClickToQif>`__ by OneClickToQif (last commit on  2017-04-23)
	OneClickToQIF consists of a set of templates and macros, which are used to export data from your spreadsheets to QIF format, as used by programs such as GnuCash, Money and Quicken. You can use the templates as provided, or adapt your own spreadsheet, so your data is automatically exported to QIF with a single click.

.. _XSLT:

XSLT
----

\* `asciidoc-conversion <https://github.com/codesmythe/asciidoc-conversion>`__ by codesmythe (last commit on  2018-08-27)
	Script and tools to convert GnuCash DocBook XML to AsciiDoc
`gnucash-docs <https://github.com/Gnucash/gnucash-docs>`__ by Gnucash (last commit on  2020-09-27)
	Documentation for GnuCash Accounting Program.
\* `gnucash-docs <https://github.com/mattig7/gnucash-docs>`__ by mattig7 (last commit on  2018-02-10)
	(No description available)
\* `Gnucash-gnucash-docs <https://github.com/jimmymccord/Gnucash-gnucash-docs>`__ by jimmymccord (last commit on  2018-05-19)
	(No description available)

.. _Unknown:

Unknown
-------

\* `accounting-plans <https://github.com/jeblad/accounting-plans>`__ by jeblad (last commit on  2018-02-09)
	Accounting plans for GnuCash
\* `accounts <https://github.com/sjtug/accounts>`__ by sjtug (last commit on  2016-09-25)
	Accounts of SJTUG in GNUCash Format
`accounts_gnucash <https://github.com/Baneeishaque/accounts_gnucash>`__ by Baneeishaque (last commit on  2020-02-29)
	(No description available)
\* `an-gnucash <https://github.com/wanjing/an-gnucash>`__ by wanjing (last commit on  2012-07-30)
	android app for gnucash
\* `ansible-role-gnucash <https://github.com/wtanaka/ansible-role-gnucash>`__ by wtanaka (last commit on  2019-08-26)
	Ansible role for installing gnucash
`bookee <https://github.com/hesy-mzh/bookee>`__ by hesy-mzh (last commit on  2020-08-22)
	Account data for GnuCash
`budget <https://github.com/bhagdave/budget>`__ by bhagdave (last commit on  2020-10-24)
	My Budget from Gnucash
\* `chloris <https://github.com/honthion/chloris>`__ by honthion (last commit on  2018-12-17)
	gnucash项目后台参考 python django
\* `Church-Accounting-Using-GnuCash <https://github.com/leggie/Church-Accounting-Using-GnuCash>`__ by leggie (last commit on  2017-11-18)
	Various excel templates containing vba scripts that makes church accounting using the open source accounting tool GnuCash as described in the blog "http://financeandaccountingforchurches.blogspot.in/2012/12/church-accounting-using-gnucash-1.html".  The files in the links mentioned there are hosted in this repository
\* `CICtoGNUcash <https://github.com/jbtruffault/CICtoGNUcash>`__ by jbtruffault (last commit on  2016-06-15)
	(No description available)
\* `commerzbank-csv4gnucash <https://github.com/zanto001/commerzbank-csv4gnucash>`__ by zanto001 (last commit on  2018-12-05)
	Tweak CSV exports from commerzbank for importing into GnuCash.
\* `ComptaTest <https://github.com/palric/ComptaTest>`__ by palric (last commit on  2017-05-05)
	Exercices programmation python/panda: importation de fichiers comptas bancaires, formatage et importation dans GnuCash
\* `CPA-006-Asap-Cheques <https://github.com/dougransom/CPA-006-Asap-Cheques>`__ by dougransom (last commit on  2017-09-26)
	Gnucash Check Configurations to print on Canadian Cheques from ASAP Cheques.
`csv2qif <https://github.com/andreaZHrustichelli/csv2qif>`__ by andreaZHrustichelli (last commit on  2020-09-15)
	Python program to convert csv file into a qif file ready to import in GNUCASH
\* `docker-gnucash <https://github.com/mbessler/docker-gnucash>`__ by mbessler (last commit on  2015-07-15)
	Containerized GnuCash
\* `docker-gnucash <https://github.com/rainu/docker-gnucash>`__ by rainu (last commit on  2017-11-20)
	A gnucash docker image
\* `docker-gnucash <https://github.com/sgalkin/docker-gnucash>`__ by sgalkin (last commit on  2018-01-31)
	gnucash docker image with SpiderOakOne integration
\* `docker-mobile-gnucash <https://github.com/au-phiware/docker-mobile-gnucash>`__ by au-phiware (last commit on  2016-12-20)
	Docker containers for justinhunt1223/mobilegnucash
`GCtranslate <https://github.com/AshokR/GCtranslate>`__ by AshokR (last commit on  2020-06-30)
	GnuCash Translation
\* `GnuCash-3part-check <https://github.com/agh1/GnuCash-3part-check>`__ by agh1 (last commit on  2012-06-06)
	A 3-part check format for GnuCash
`gnucash-accounts <https://github.com/ordtrogen/gnucash-accounts>`__ by ordtrogen (last commit on  2019-12-18)
	Some Account Hierarchy Templates for GnuCash in Swedish
\* `gnucash-android-master <https://github.com/abdullahwale/gnucash-android-master>`__ by abdullahwale (last commit on  2018-10-19)
	(No description available)
\* `gnucash-api <https://github.com/jjuanda/gnucash-api>`__ by jjuanda (last commit on  2013-12-14)
	REST APIs for GnuCash files
`gnucash-build-debian <https://github.com/willelop/gnucash-build-debian>`__ by willelop (last commit on  2020-09-06)
	Installs in Debian all the required dependencies for building gnucash
\* `gnucash-compose <https://github.com/daveyb/gnucash-compose>`__ by daveyb (last commit on  2017-03-11)
	docker-compose file(s) to bring up local gnucash cluster
\* `gnucash-data <https://github.com/anshprat/gnucash-data>`__ by anshprat (last commit on  2015-06-02)
	data files for my gnucash encrypted with gpg
\* `gnucash-docker <https://github.com/KaiLemke/gnucash-docker>`__ by KaiLemke (last commit on  2017-12-18)
	containerized gnucash 2.6
\* `gnucash-docker <https://github.com/dbcesar/gnucash-docker>`__ by dbcesar (last commit on  2018-04-16)
	Dockerfile and docker-compose to install and run gnucash 3.0 from a docker container
\* `gnucash-docs <https://github.com/cygwinports/gnucash-docs>`__ by cygwinports (last commit on  2018-04-09)
	Cygwin gnucash-docs packaging
\* `gnucash-fire-tools <https://github.com/KarolOlko/gnucash-fire-tools>`__ by KarolOlko (last commit on  2018-10-16)
	Slicing gnucash DB for more insights
\* `gnucash-guide-asciidoc <https://github.com/codesmythe/gnucash-guide-asciidoc>`__ by codesmythe (last commit on  2018-08-23)
	The GnuCash Tutorial and Concept Guide, converted to Asciidoc
\* `gnucash-my_chart_of_accounts <https://github.com/5472qaywsx/gnucash-my_chart_of_accounts>`__ by 5472qaywsx (last commit on  2019-02-25)
	my personal chart of accounts for gnucash
`gnucash-pot <https://github.com/fellen/gnucash-pot>`__ by fellen (last commit on  2020-03-25)
	Portable Template of GnuCash
\* `gnucash-queries <https://github.com/g2010a/gnucash-queries>`__ by g2010a (last commit on  2016-10-20)
	Queries to extract data from Gnucash's database
\* `gnucash-rest <https://github.com/mhitchens/gnucash-rest>`__ by mhitchens (last commit on  2014-05-03)
	A Spring Data/Spring REST interface to a gnucash data file
`gnucash-stuff <https://github.com/ajablonski/gnucash-stuff>`__ by ajablonski (last commit on  2020-08-31)
	(No description available)
`GnuCash-Tutorials <https://github.com/duguqiubailee/GnuCash-Tutorials>`__ by duguqiubailee (last commit on  2020-10-19)
	(No description available)
\* `gnucash-web <https://github.com/djbrown/gnucash-web>`__ by djbrown (last commit on  2016-01-01)
	(No description available)
`GNUCASH.APP-ERICK-CLEWIS <https://github.com/ErickClewisAccountsdatamoneymarketing/GNUCASH.APP-ERICK-CLEWIS>`__ by ErickClewisAccountsdatamoneymarketing (last commit on  2020-03-03)
	USD$ DATABASE OPEN SOURCE DATA
\* `gnucash_auto <https://github.com/torchtarget/gnucash_auto>`__ by torchtarget (last commit on  2017-08-18)
	A simple transaction importer for Gnucash
\* `gnucashdeb <https://github.com/twt2/gnucashdeb>`__ by twt2 (last commit on  2019-09-28)
	(No description available)
\* `gnucashdockeraws <https://github.com/fervincent/gnucashdockeraws>`__ by fervincent (last commit on  2019-03-29)
	(No description available)
\* `GnucashSW <https://github.com/Oldobaba/GnucashSW>`__ by Oldobaba (last commit on  2018-07-04)
	(No description available)
`gnucashTelegram <https://github.com/f-angi/gnucashTelegram>`__ by f-angi (last commit on  2020-02-14)
	(No description available)
\* `JsCash <https://github.com/rafaelbeckel/JsCash>`__ by rafaelbeckel (last commit on  2019-04-24)
	Double entry accounting system inspired by GNUCash
\* `kg7je <https://github.com/twt2/kg7je>`__ by twt2 (last commit on  2019-09-12)
	Stephen Butler's Debian Package Files for GnuCash
\* `knab-gnucash-converter <https://github.com/bkrijg/knab-gnucash-converter>`__ by bkrijg (last commit on  2017-05-03)
	A python script for converting KNAB bankstatement information files into a suitable gnucash csv import file
\* `lepturus <https://github.com/honthion/lepturus>`__ by honthion (last commit on  2018-12-17)
	gnucash项目后台H5 vue
`moflow <https://github.com/msobkow/moflow>`__ by msobkow (last commit on  2020-10-22)
	Money Flow is a revisioning of GNU Cash as a web-enabled Spring Tool Suite 4 application set
\* `nordea-csv2qif <https://github.com/martinolsen/nordea-csv2qif>`__ by martinolsen (last commit on  2012-09-09)
	Convert Nordea CSV exports to QIF format (usable by GnuCash and others)
`org.gnucash.GnuCash <https://github.com/flathub/org.gnucash.GnuCash>`__ by flathub (last commit on  2020-09-27)
	(No description available)
\* `PayPalConvert <https://github.com/rowantree/PayPalConvert>`__ by rowantree (last commit on  2015-11-04)
	Convert PayPal csv files to qif for loading into GnuCash
\* `perotis <https://github.com/honthion/perotis>`__ by honthion (last commit on  2018-12-17)
	gnucash项目App flutter
\* `rabo2qif <https://github.com/milovanderlinden/rabo2qif>`__ by milovanderlinden (last commit on  2011-01-25)
	export mut.txt to qif for gnucash
\* `resource-gnucash-build <https://github.com/hgati/resource-gnucash-build>`__ by hgati (last commit on  2018-03-21)
	(No description available)
`Singularity-GNUCash <https://github.com/rgrandin/Singularity-GNUCash>`__ by rgrandin (last commit on  2019-12-30)
	Fedora 28 build of GNUCash
\* `splitwise-to-gnucash <https://github.com/yfede/splitwise-to-gnucash>`__ by yfede (last commit on  2018-08-07)
	A script to grab transactions from Splitwise and export them in CSV form for import in GnuCash
\* `tk_ansible_gnucash_vscode01 <https://github.com/tkerns1965/tk_ansible_gnucash_vscode01>`__ by tkerns1965 (last commit on  2019-08-28)
	(No description available)
\* `Vishal-Ramteke <https://github.com/vishal7788/Vishal-Ramteke>`__ by vishal7788 (last commit on  2019-09-01)
	GnuCash Mobile Automation Test
\* `Vishal-Ramteke <https://github.com/vishal7788/Vishal-Ramteke>`__ by vishal7788 (last commit on  2019-09-01)
	GnuCash Mobile Automation Test
`webcash <https://github.com/turlog/webcash>`__ by turlog (last commit on  2020-06-17)
	WebCash is a proxy service that allows connecting to GNUCash databases with REST API.

